(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
  typeof define === 'function' && define.amd ? define(['exports'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.UseSvelte = {}));
})(this, (function (exports) { 'use strict';

  // <div use:tooltip content='some content'></div>
  var tooltip = (element => {
    let div;
    let content;

    function mouseOver(event) {
      content = element.getAttribute("content");

      if (content) {
        element.removeAttribute("content");
        div = document.createElement("div");
        div.textContent = content;
        div.style = `
      top: ${event.pageX + 5}px; 
      left: ${event.pageY + 5}px;
      position: absolute;
      border-radius: 0.25rem;
      border-width: 1px;
      border-color: rgb(31 41 55 / 0.2);
      background-color: rgb(255 255 255 / 1);
      padding-left: 0.5rem;
      padding-right: 0.5rem;
      font-size: 0.875rem;
      line-height: 1.25rem;
      font-weight: 600;
      text-transform: uppercase;
      color: rgb(0 0 0 / 1);
      box-shadow: 0 0 #0000, 0 0 #0000, 0 1px 3px 0 rgb(0 0 0 / 0.1),
        0 1px 2px -1px rgb(0 0 0 / 0.1);`;
        div.classList = "use_svelte_tooltip";
        document.body.appendChild(div);
      }
    }

    function mouseMove(event) {
      div.style.left = `${event.pageX + 5}px`;
      div.style.top = `${event.pageY + 5}px`;
    }

    function mouseLeave() {
      document.body.removeChild(div);
      element.setAttribute("content", content);
    }

    element.addEventListener("mouseover", mouseOver);
    element.addEventListener("mouseleave", mouseLeave);
    element.addEventListener("mouseout", mouseLeave);
    element.addEventListener("mousemove", mouseMove);
    return {
      destroy() {
        element.removeEventListener("mouseover", mouseOver);
        element.removeEventListener("mouseleave", mouseLeave);
        element.removeEventListener("mousemove", mouseMove);
      }

    };
  });

  // use:clickOutside on:clickOutside={() => close()}
  var clickOutside = (node => {
    const handleClick = event => {
      if (node && !node.contains(event.target) && !event.defaultPrevented) {
        node.dispatchEvent(new CustomEvent("clickOutside", node));
      }
    };

    document.addEventListener("click", handleClick, true);
    return {
      destroy() {
        document.removeEventListener("click", handleClick, true);
      }

    };
  });

  // <div use:shortcut={{shift: true, control: true, code: 'KeyA', fn: () => trigger()}} on:click={() => trigger()}></div>
  // will trigger click event if fn not present
  var shortcut = ((node, params) => {
    let handler;

    const removeHandler = () => window.removeEventListener("keydown", handler);

    const setHandler = () => {
      removeHandler();
      if (!params) return;

      handler = e => {
        e.preventDefault();
        params.fn ? params.fn() : node.click();
      };

      window.addEventListener("keydown", handler);
    };

    setHandler();
    return {
      update: setHandler,
      destroy: removeHandler
    };
  });

  const options = {
    root: null,
    rootMargin: "0px",
    threshold: 0
  };
  var lazy = ((image, src) => {
    if ("IntersectionObserver" in window) {
      const loaded = () => {
        image.style.opacity = "1";
      };

      const observer = new IntersectionObserver(entries => {
        if (entries[0].isIntersecting) {
          image.src = src;

          if (image.complete) {
            loaded();
          } else {
            image.addEventListener("load", loaded);
          }
        }
      }, options);
      observer.observe(image);
      return {
        destroy() {
          image.removeEventListener("load", loaded); // clean up the event listener
        }

      };
    } else {
      const img = new Image();
      img.src = src;

      img.onload = () => {
        image.setAttribute("src", src);
      };

      return {
        destroy() {}

      };
    }
  });

  // use:autofocus (will focus on page load)
  var autofocus = (node => {
    node.focus();
  });

  var clickToCopy = ((node, target) => {
    const copyText = async () => {
      let text = target ? document.querySelector(target).innerText : node.innerText;

      try {
        await navigator.clipboard.writeText(text);
        node.dispatchEvent(new CustomEvent("copySuccess", {
          bubbles: true
        }));
      } catch (error) {
        node.dispatchEvent(new CustomEvent("copyError", {
          bubbles: true,
          detail: error
        }));
      }
    };

    node.addEventListener("click", copyText);
    return {
      destroy() {
        node.removeEventListener("click", copyText);
      }

    };
  });

  exports.autofocus = autofocus;
  exports.clickOutside = clickOutside;
  exports.clickToCopy = clickToCopy;
  exports.lazy = lazy;
  exports.shortcut = shortcut;
  exports.tooltip = tooltip;

}));
